@@ -5,6 +5,7 @@ mod context;
 mod engine;
 mod engine_manager;
 mod geometry;
+mod macros;
 mod menu_manager;
 mod message_manager;
 mod observatory;
@@ -19,6 +20,7 @@ pub use context::*;
 pub use engine::*;
 pub use engine_manager::*;
 pub use geometry::*;
+pub use macros::*;
 pub use menu_manager::*;
 pub use message_manager::*;
 pub use observatory::*;
